@@ -4,12 +4,18 @@
   '(("MIDORI"             . "$(B?i(B")
     ("MIDORI-NO-TAMA"     . "$(B?iG7<n(B")
     ("TSUYU"              . "$(BO*(B")
+    ("AWSAKA"             . "$(B0):d(B")
+    ("SHOUBU"             . "$(B>T3w(B")
     ("KASURI"             . "$(Be3(B")
     ("TACHIBANA"          . "$(B5L(B")
+    ("YAMA-TACHIBANA"     . "$(B;35L(B")
     ("HIINA"              . "$(B?w(B")
     ("FUTAAWI"            . "$(BFsMu(B")
     ("EBIZOME"            . "$(BIrF:@w(B")
     ("HACHISU"            . "$(BO!(B")
+    ("SASHINUKI"          . "$(B;X4S(B")
+    ("TANAHASHI"          . "$(BC*66(B")
+    ("UKIHASHI"           . "$(BIb66(B")
     ("KAKITSUBATA"        . "$(BEN<c(B")))
 
 (provide 'rail-table-meadow)
